All Classes and Interfaces

Classes
Class
Description
Matcher for BugInstance that allows to match on various criteria such as bug type, class name, method name, field name, variable name, line number, confidence and JSP file.
Builder for creating a BugInstanceMatcher.
ClassFileLocator is a utility class that provides methods to locate class files, JSP files, and JAR files based on their paths or names.
The Class CountMatcher.